@@ -29,7 +29,8 @@ except ImportError:
 start = """
 <table border="0" bgcolor="%(bgcolor)s" cellspacing="0" cellpadding="0"%(tablewidth)s>
  <tr>
-    <td><table border="0" cellspacing="0" cellpadding="0">
+    <td>
+      <table border="0" cellspacing="0" cellpadding="0">
       <tr>
           <td align="center" valign="middle" bgcolor="%(leftbgcolor)s">
               <font color="%(leftfgcolor)s"style="font-family:verdana,sans-serif;font-size:12 px;"><b>%(left)s</b></font>
@@ -37,6 +38,7 @@ start = """
           %(middle)s
           %(right)s
      </tr>
+     </table>
     </td>
  </tr>
 </table>
